==> cms-db_v0.5.1.tar.gz: admin/sort1.php <==
<?php
/*  cms-db  Copyright (C) 2007-2008 Jan Hoffmann
    This program comes with ABSOLUTELY NO WARRANTY; for details see /admin/version.php.
    This is free software, and you are welcome to redistribute it under certain conditions; see /admin/version.php for details.  */
include('checkuser.inc.php');
checkuser('pages');
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
     "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
<head>
<title>CMS Inhalt</title>
<link rel="stylesheet" type="text/css" href="style.css">
<link rel="stylesheet" type="text/css" href="tool-man/lists.css">
<style type="text/css">
<!--
	ul.boxy li { margin: 0px; }
	#sortlist { margin-top: -4px; }
	#sortlist li { margin-top: 4px; }
	#boxes {
		font-family: Arial, sans-serif;
		list-style-type: none;
		margin: 0px;
		padding: 0px;
		width: 300px;
	}
	#boxes li {
		cursor: move;
		position: relative;
		float: left;
		margin: 2px 2px 0px 0px;
		width: 33px;
		height: 28px;
		border: 1px solid #000;
		text-align: center;
		padding-top: 5px;
		background-color: #eeeeff;
	}

-->
</style>
<script language="JavaScript" type="text/javascript" src="tool-man/core.js"></script>
<script language="JavaScript" type="text/javascript" src="tool-man/events.js"></script>
<script language="JavaScript" type="text/javascript" src="tool-man/css.js"></script>
<script language="JavaScript" type="text/javascript" src="tool-man/coordinates.js"></script>
<script language="JavaScript" type="text/javascript" src="tool-man/drag.js"></script>
<script language="JavaScript" type="text/javascript" src="tool-man/dragsort.js"></script>
<script language="JavaScript" type="text/javascript" src="tool-man/cookies.js"></script>
<script language="JavaScript" type="text/javascript"><!--
	var dragsort = ToolMan.dragsort()
	var junkdrawer = ToolMan.junkdrawer()

	window.onload = function() {
		junkdrawer.restoreListOrder("sortlist")

		dragsort.makeListSortable(document.getElementById("sortlist"), verticalOnly, saveOrder)
	}

	function verticalOnly(item) {
		item.toolManDragGroup.verticalOnly()
	}

	function saveOrder(item) {
		var group = item.toolManDragGroup
		var list = group.element.parentNode
		var id = list.getAttribute("id")
		if (id == null) return
		group.register('dragend', function() {
			ToolMan.cookies().set("list-" + id,
					junkdrawer.serializeList(list), 365)
		})
	}

	function inspect() {
         	location.href = "sort2.php?sec=<?php echo str_replace("/","%2F",$_GET['sec']) ?>&data=" + ToolMan.junkdrawer().serializeList(document.getElementById('sortlist')) + "&<?php echo SID ?>";
		//alert(ToolMan.junkdrawer().serializeList(document.getElementById('sortlist')))
	}

	//-->
</script>
</head>
<body>

<h1>Seiten in Sektion <?php echo $_GET['sec'] ?> sortieren</h1>
<p>
	<ul id="sortlist" class="boxy">
<?php
  $exists = "no";
  $ordner = $_GET['sec'];
  $handle = opendir($ordner);
  while (false !== ($file = readdir($handle))) {
    if($file != "." && $file != "..") {
      $files[] = $file;
    }
  }
  natcasesort($files);
  foreach($files as $file) {
    $show = substr($file, 3);
    $show = str_replace("_"," ",$show);
    $show = str_replace("SLASH","/",$show);
    $show = str_replace("AND" ,"&", $show);
    if($file != "01,Home") {
      echo "\t\t\t";
      echo '<li itemID="'.$file.'">'.$show.'</li>';
      $exists = "yes";
    }
  }
  closedir($handle);
  if ($exists == "no") { echo "Es existieren keine Seiten, die sortiert werden k&ouml;nnen."; }
?>
	</ul>
</p>
<p>
<?php
if ($exists == "yes") {
?>
	<input class="inspector" type="button" value="Sortierung speichern" onclick="inspect()" style="margin: 0px; padding: 0px; font-size: 11px;">
<?php
} else {
?>
	<a href="pages.php?<?php echo SID ?>">zur&uuml;ck</a>
<?php
}
?>
</p>
<p>
	<i>Hinweise: Die Home-Dateien k&ouml;nnen nicht ge&auml;ndert werden!</i>
</p>
<p>
	<i>Falls die Seiten in der falschen Reihenfolge angezeigt werden, versuchen Sie bitte in Ihrem Browser die Cookies zu l&ouml;schen.</i>
</p>
<noscript>
Zum Sortieren der Seiten und Sektionen muss JavaScript aktiviert sein.
</noscript>

</body>
</html>

==> cms-db_v0.6.tar.gz: admin/sort1.php <==
<?php
/*  cms-db  Copyright (C) 2007-2009 Jan Hoffmann
    This program comes with ABSOLUTELY NO WARRANTY; for details see /admin/version.php.
    This is free software, and you are welcome to redistribute it under certain conditions; see /admin/version.php for details.  */
include('checkuser.inc.php');
checkuser('pages');
include('locale.inc.php');
$locale = new LocalizingClass('pages');

include('../functions_url.inc.php');
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
     "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
<head>
<title><?php locale('title_sort') ?></title>
<meta http-equiv="content-type" content="text/html; charset=utf-8" />
<link rel="stylesheet" type="text/css" href="style.css">
<link rel="stylesheet" type="text/css" href="tool-man/lists.css">
<style type="text/css">
<!--
	ul.boxy li { margin: 0px; width: 200px; }
	#sortlist { margin-top: -4px; }
	#sortlist li { margin-top: 4px; }
-->
</style>
<script language="JavaScript" type="text/javascript" src="tool-man/core.js"></script>
<script language="JavaScript" type="text/javascript" src="tool-man/events.js"></script>
<script language="JavaScript" type="text/javascript" src="tool-man/css.js"></script>
<script language="JavaScript" type="text/javascript" src="tool-man/coordinates.js"></script>
<script language="JavaScript" type="text/javascript" src="tool-man/drag.js"></script>
<script language="JavaScript" type="text/javascript" src="tool-man/dragsort.js"></script>
<!--<script language="JavaScript" type="text/javascript" src="tool-man/cookies.js"></script>-->
<script language="JavaScript" type="text/javascript"><!--
	var dragsort = ToolMan.dragsort()
	var junkdrawer = ToolMan.junkdrawer()

	window.onload = function() {
		dragsort.makeListSortable(document.getElementById("sortlist"), verticalOnly)
	}

	function verticalOnly(item) {
		item.toolManDragGroup.verticalOnly()
	}

	function inspect() {
         	location.href = "sort2.php?sec=<?php echo $_GET['sec'] ?>&data=" + ToolMan.junkdrawer().serializeList(document.getElementById('sortlist')) + "&<?php echo SID ?>";
	}

	//-->
</script>
</head>
<body>

<h1><?php locale('title_sort') ?></h1>
<noscript>
	<p><?php locale('desc_sort-nojs') ?></p>
</noscript>
<p>
	<ul id="sortlist" class="boxy">
<?php
  $exists = "no";
  if ($_GET['sec'] == 'root') {
    $ordner = '../data/pages/';
  } else {
    $ordner = get_filename_from_url($_GET['sec']);
    $ordner = '../data/pages'.substr($ordner, 0, strrpos($ordner, '/'));
  }
  $handle = opendir($ordner);
  while (false !== ($file = readdir($handle))) {
    if($file != "." && $file != "..") {
      $files[] = $file;
    }
  }
  natcasesort($files);
  foreach($files as $file) {
    $show = substr($file, 3);
    $show = str_replace("_"," ",$show);
    $show = str_replace("SLASH","/",$show);
    $show = str_replace("AND" ,"&", $show);
    if($file != "01,Home") {
      echo "\t\t\t";
      echo '<li itemID="'.$file.'">'.$show.'</li>';
      $exists = "yes";
    }
  }
  closedir($handle);
  if ($exists == "no") { locale('desc_sort-no-pages'); }
?>
	</ul>
</p>
<p>
<?php
if ($exists == "yes") {
?>
	<input class="inspector" type="button" value="<?php locale('button_save') ?>" onclick="inspect()" style="margin: 0px; padding: 0px; font-size: 11px;">
<?php
} else {
?>
	<a href="pages.php?<?php echo SID ?>"><?php locale('link_back') ?></a>
<?php
}
?>
</p>

</body>
</html>
